@@ -22,8 +22,8 @@ Audio::Convert::Samplerate - perform samplerate conversion on audio data
     my Audio::Convert::Samplerate $conv-obj =  Audio::Convert::Samplerate.new(channels => $in-obj.channels);
     my Int $sr = ($in-obj.samplerate * $ratio).Int;
 
-    my Audio::Sndfile $out-obj = Audio::Sndfile.new(filename   => $test-file-out, 
-                                                    channels   => $in-obj.channels, 
+    my Audio::Sndfile $out-obj = Audio::Sndfile.new(filename   => $test-file-out,
+                                                    channels   => $in-obj.channels,
                                                     format     => $in-obj.format,
                                                     samplerate => $sr,  :w);
 
@@ -50,7 +50,7 @@ data using libsamplerate (http://www.mega-nerd.com/libsamplerate/)
 the implementation of which is both fairly quick and accurate.
 
 The interface is fairly simple, providing methods to work with native
-C arrays where the raw speed is important as well as perl arrays where
+C arrays where the raw speed is important as well as Raku arrays where
 further processing is required on the data.
 
 The native library is designed to work only with 32 bit floating point
@@ -78,9 +78,9 @@ the enum C<Type> with one of thse values:
 
 =item Medium
 
-=item Fastest 
+=item Fastest
 
-=item OrderHold 
+=item OrderHold
 
 =item Linear
 
@@ -172,7 +172,7 @@ methods will throw an exception if supplied an invalid ratio.
 
 =end pod
 
-class Audio::Convert::Samplerate:ver<v0.0.5>:auth<github:jonathanstowe> {
+class Audio::Convert::Samplerate:ver<0.0.9>:auth<github:jonathanstowe>:api<1.0> {
     use NativeCall;
     use NativeHelpers::Array;
 
@@ -183,9 +183,9 @@ class Audio::Convert::Samplerate:ver<v0.0.5>:auth<github:jonathanstowe> {
     class X::ConvertError is Exception {
         has Int $.error-code = 0;
 
-        sub src_strerror(int32 $error) returns Str is native('samplerate',v0) { * }
+        sub src_strerror(int32 $error --> Str ) is native('samplerate',v0) { * }
 
-        method message() returns Str {
+        method message( --> Str ) {
             src_strerror($!error-code);
         }
     }
@@ -193,7 +193,7 @@ class Audio::Convert::Samplerate:ver<v0.0.5>:auth<github:jonathanstowe> {
     class X::InvalidRatio is Exception {
         has Num $.ratio is required;
 
-        method message() returns Str {
+        method message( --> Str ) {
             "The convertion ratio { $!ratio } is not valid";
         }
     }
@@ -224,9 +224,9 @@ class Audio::Convert::Samplerate:ver<v0.0.5>:auth<github:jonathanstowe> {
 
     class State is repr('CPointer') {
 
-        sub src_new(int32 $converter-type, int32 $channels, int32 $error) returns State is native('samplerate',v0) { * }
+        sub src_new(int32 $converter-type, int32 $channels, int32 $error --> State ) is native('samplerate',v0) { * }
 
-        method new(Type $type, Int $channels) returns State {
+        method new(Type $type, Int $channels --> State) {
             my Int $error = 0;
             my $state = src_new($type.Int, $channels, $error);
 
@@ -237,9 +237,9 @@ class Audio::Convert::Samplerate:ver<v0.0.5>:auth<github:jonathanstowe> {
             $state;
         }
 
-        sub src_process(State $st, Data $d is rw) returns int32 is native('samplerate',v0) { * }
+        sub src_process(State $st, Data $d is rw --> int32) is native('samplerate',v0) { * }
 
-        multi method process(Data $data is rw) returns Data {
+        multi method process(Data $data is rw --> Data ) {
             my $rc = src_process(self, $data);
 
             if $rc != 0 {
@@ -249,18 +249,13 @@ class Audio::Convert::Samplerate:ver<v0.0.5>:auth<github:jonathanstowe> {
         }
 
         # put this in here as it simplifies matters
-        sub src_is_valid_ratio (num64 $ratio) returns int32 is native('samplerate',v0) { * }
+        sub src_is_valid_ratio (num64 $ratio --> int32 ) is native('samplerate',v0) { * }
 
-        method is-valid-ratio(Num $ratio) returns Bool {
-            if src_is_valid_ratio($ratio) {
-                True;
-            }
-            else {
-                False;
-            }
+        method is-valid-ratio(Num $ratio --> Bool ) {
+            so src_is_valid_ratio($ratio);
         }
 
-        sub src_set_ratio(State $state, num64 $new_ratio) returns int32 is native('samplerate',v0) { * }
+        sub src_set_ratio(State $state, num64 $new_ratio --> int32 ) is native('samplerate',v0) { * }
 
         method set-ratio(Num $new-ratio) {
             my $rc = src_set_ratio(self, $new-ratio);
@@ -270,7 +265,7 @@ class Audio::Convert::Samplerate:ver<v0.0.5>:auth<github:jonathanstowe> {
             }
         }
 
-        sub src_reset(State) returns int32 is native('samplerate',v0) { * }
+        sub src_reset(State --> int32 ) is native('samplerate',v0) { * }
 
         method reset() {
             my $rc = src_reset(self);
@@ -297,14 +292,14 @@ class Audio::Convert::Samplerate:ver<v0.0.5>:auth<github:jonathanstowe> {
         $!state = State.new($!type, $!channels);
     }
 
-    sub src_get_version() returns Str is native('samplerate',v0) { * }
+    sub src_get_version( --> Str ) is native('samplerate',v0) { * }
 
-    method samplerate-version() returns Version {
+    method samplerate-version( --> Version ) {
         my $v = src_get_version();
         Version.new($v);
     }
 
-    multi method process(CArray[num32] $data-in, Int $input-frames, Num() $src-ratio, Bool $last = False) returns RawProcess {
+    multi method process(CArray[num32] $data-in, Int $input-frames, Num() $src-ratio, Bool $last = False --> RawProcess ) {
 
         if not self.is-valid-ratio($src-ratio) {
             X::InvalidRatio.new.throw;
@@ -319,7 +314,7 @@ class Audio::Convert::Samplerate:ver<v0.0.5>:auth<github:jonathanstowe> {
         [ $data.data-out, $data.output-frames-gen ];
     }
 
-    method !process-other(Mu $type, CArray $data-in, Int $input-frames, Num() $src-ratio, Bool $last, &to, &from) returns RawProcess {
+    method !process-other(Mu $type, CArray $data-in, Int $input-frames, Num() $src-ratio, Bool $last, &to, &from --> RawProcess ) {
         my CArray[num32] $new-data = CArray[num32].new;
         my Int $total-frames = ($input-frames * $!channels).Int;
         $new-data[$total-frames] = Num(0);
@@ -332,27 +327,27 @@ class Audio::Convert::Samplerate:ver<v0.0.5>:auth<github:jonathanstowe> {
         [ $int-out, $frames-out ]
     }
 
-    multi method process(CArray[int16] $data-in, Int $input-frames, Num() $src-ratio, Bool $last = False) returns RawProcess {
+    multi method process(CArray[int16] $data-in, Int $input-frames, Num() $src-ratio, Bool $last = False --> RawProcess ) {
         self!process-other(int16, $data-in, $input-frames, $src-ratio, $last, &src_short_to_float_array, &src_float_to_short_array);
     }
 
-    multi method process(CArray[int32] $data-in, Int $input-frames, Num() $src-ratio, Bool $last = False) returns RawProcess {
+    multi method process(CArray[int32] $data-in, Int $input-frames, Num() $src-ratio, Bool $last = False --> RawProcess ) {
         self!process-other(int32, $data-in, $input-frames, $src-ratio, $last, &src_int_to_float_array, &src_float_to_int_array);
     }
 
-    method !process-array(Mu $type, @items, Num() $src-ratio, Bool $last = False) returns Array {
+    method !process-array(Mu $type, @items, Num() $src-ratio, Bool $last = False --> Array ) {
         my CArray $carray = copy-to-carray(@items, $type);
         my $frames = (@items.elems / $!channels).Int;
         my $ret = self.process($carray, $frames, $src-ratio, $last);
         copy-to-array($ret[0], $ret[1] * $!channels);
     }
-    method process-float(@items, Num() $src-ratio, Bool $last = False) returns Array {
+    method process-float(@items, Num() $src-ratio, Bool $last = False --> Array ) {
         self!process-array(num32, @items, $src-ratio, $last);
     }
-    method process-short(@items, Num() $src-ratio, Bool $last = False) returns Array {
+    method process-short(@items, Num() $src-ratio, Bool $last = False --> Array ) {
         self!process-array(int16, @items, $src-ratio, $last);
     }
-    method process-int(@items, Num() $src-ratio, Bool $last = False) returns Array {
+    method process-int(@items, Num() $src-ratio, Bool $last = False --> Array ) {
         self!process-array(int32, @items, $src-ratio, $last);
     }
 
@@ -364,4 +359,4 @@ class Audio::Convert::Samplerate:ver<v0.0.5>:auth<github:jonathanstowe> {
 
 }
 
-# vim: expandtab shiftwidth=4 ft=perl6
+# vim: expandtab shiftwidth=4 ft=raku
